@@ -215,6 +215,17 @@ public final class FeatureAdapter {
         return imageAdapter.read(url, false, false);
     }
 
+    /**
+     * Reads an image using the current {@link ImageAdapter}.
+     * @param url image URI to read
+     * @return a <code>BufferedImage</code> containing the decoded contents of the input, or <code>null</code>.
+     * @throws java.net.MalformedURLException if the URI could not be converted to a URL
+     * @throws IOException if an error occurs during reading.
+     */
+    public static BufferedImage readImage(URI url) throws IOException {
+        return imageAdapter.read(url.toURL(), false, false);
+    }
+
     /**
      * Translates a text using the current {@link TranslationAdapter}.
      * @param text the text to translate.
@@ -298,10 +309,8 @@ public final class FeatureAdapter {
             if (Desktop.isDesktopSupported() && Desktop.getDesktop().isSupported(Desktop.Action.BROWSE)) {
                 try {
                     Desktop.getDesktop().browse(new URI(url));
-                } catch (IOException e) {
-                    e.printStackTrace();
-                } catch (URISyntaxException e) {
-                    e.printStackTrace();
+                } catch (IOException | URISyntaxException e) {
+                    getLogger(FeatureAdapter.class).log(Level.SEVERE, e.getMessage(), e);
                 }
             } else {
                 getLogger(FeatureAdapter.class).log(Level.SEVERE, tr("Opening link not supported on current platform (''{0}'')", url));
